# Django Background Tasks Updated
Django Background Task is a database-backed work queue for Django, loosely based
around [Ruby's DelayedJob](https://github.com/tobi/delayed_job) library. This project was
adopted and adapted from [lilspikey's](https://github.com/lilspikey/) `django-background-task`. This fork includes minor fixes to support Django 4.

To avoid conflicts on PyPI we renamed it to django-background-tasks-updated (plural).
# Docs
See [Read the docs](http://django-background-tasks.readthedocs.io/en/latest/)
# Donations
``django-background-tasks`` is free software. If you find it useful and would like to give back, please consider making
a donation to the original author using [Bitcoin](https://blockchain.info/payment_request?address=34vD9fADYX9QAcMfJUB4c2pYd19SG2toZ9) or [PayPal](https://www.paypal.me/arteriagmbh). Thank you!
